require 'base64'
require 'digest'

module PuppetX
  module EnterpriseModules
    # docs
    module AttributeHelpers
      def unsafe_munge(value)
        #
        # Make all key lowercase symbols. This is the way the net-ldap returns them
        #
        ::Hash[value.map { |k, v| [k.downcase.to_sym, v] }]
      end

      def unsafe_validate(value)
        raise "Currently: #{value}, but it should be a Hash." unless value.is_a?(::Hash)
      end

      def is
        case retrieve
        when :absent then {}
        else retrieve
        end
      end

      def changed_attributes(variables, is, should)
        return variables if (is == :absent) || (should == :absent)
        variables.select { |e| !compare(e, is, should) }
      end

      def updated_attributes(is, should)
        changed_attributes(value.keys, is, should)
      end

      def compare(attribute, is, should)
        if should_be_transformed(attribute)
          transformed_compare(attribute, is, should)
        elsif is[attribute].is_a?(Array)
          is[attribute].sort == Array(should[attribute]).sort
        else
          is[attribute]. == should[attribute]
        end
      end

      def should_be_transformed(attribute)
        if resource.transform
          resource.transform.keys.include?(attribute.to_s)
        else
          false
        end
      end

      def transformed_compare(attribute, is, should)
        raise "#{attribute} should not be transformed" unless should_be_transformed(attribute)
        function_name = resource.transform[attribute.to_s]
        if is[attribute].is_a?(Array)
          compare_valid_value(function_name, should[attribute], is[attribute])
        else
          call_transformer(function_name, should[attribute], is[attribute])
        end
      end

      def call_transformer(transformer, should, is)
        method_name = "#{transformer}_compare".to_sym
        raise "transformer #{transformer} doesn't exist." unless respond_to?(method_name)
        send(method_name, should, is)
      end

      #
      # Calls the transformer for the values in the array of is values
      # If one comes back with a valid true or false, return this value
      # If only errors are raised by the transformer, return an error stating
      # we cannot transform the current value
      #
      def compare_valid_value(function_name, should, is)
        is.each do | array_value|
          begin
            value = call_transformer(function_name, should, array_value)
            return value
          rescue RuntimeError
            next
          end
        end
        fail "The returned attribute value doesn't contain value recognised by transformer."
      end
    end
  end
end
